<?php

if (!defined('ABSPATH')) {
	exit;
}

class WC_HC_Categories_Page {
	function __construct() {
		$this->_communicator = new WC_HC_Communicator();

		$articles_feature_enabled = apply_filters('e5_hc_article_creation_feature_enabled', false);
		if (!$articles_feature_enabled) {
			return;
		}

		// Register Admin Menu Entry
		add_action('admin_menu', [$this, 'add_admin_menu_entry'], 99);
		add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
		add_action('admin_init', [$this, 'save']);
	}

	function add_admin_menu_entry() {
		add_submenu_page(
			'edit.php?post_type=product',
			__('helloCash Categories', 'wc-hellocash'),
			__('helloCash Categories', 'wc-hellocash'),
			'manage_options',
			'e5-hc-categories',
			[$this, 'render_page'],
			99
		);
	}

	function enqueue_scripts() {
		wp_enqueue_style('woocommerce_admin_styles');
	}

	function save() {
		// Check action
		if (!isset($_POST['e5_hc_action']) || $_POST['e5_hc_action'] !== 'save_hc_categories') {
			return;
		}

		// Validate nonce
		if (!wp_verify_nonce(wp_unslash($_POST['_wpnonce']), 'bulk-e5_hc_categories')) {
			return;
		}

		// Save helloCash articles
		foreach ($_POST as $key => $value) {
			if (substr($key, 0, 16) === '_e5_hc_category_') {
				$category_id = substr($key, 16);

				delete_option('e5_hc_category_map_'.$category_id);

				if (!empty($value)) {
					update_option('e5_hc_category_map_'.$category_id, $value);
				}
			}
		}
	}

	function render_page() {
		$table = new WC_HC_Categories_Table();
		$table->prepare_items();
		?>
		<div class="wrap">
			<h1 class="wp-heading-inline"><?php echo __('helloCash Categories', 'wc-hellocash'); ?></h1>
			<hr class="wp-header-end">
			<form method="post">
				<input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
				<input type="hidden" name="e5_hc_action" value="save_hc_categories" />
				<p class="search-box" style="clear: both; margin-top: 1em;">
					<input type="submit" class="button" value="<?php echo __('Save Categories', 'wc-hellocash'); ?>" />
				</p>
				<?php
				$table->display();
				?>
			</form>
		</div>
		<?php
	}
}
