<?php

if (!defined('ABSPATH')) {
	exit;
}

class WC_HC_Products_Page {
	function __construct() {
		$this->_communicator = new WC_HC_Communicator();

		// Register Admin Menu Entry
		add_action('admin_menu', [$this, 'add_admin_menu_entry'], 99);
		add_action('admin_enqueue_scripts', [$this, 'enqueue_scripts']);
		add_action('admin_init', [$this, 'save']);
	}

	function add_admin_menu_entry() {
		add_submenu_page(
			'edit.php?post_type=product',
			__('helloCash References', 'wc-hellocash'),
			__('helloCash', 'wc-hellocash'),
			'manage_options',
			'e5-hc-references',
			[$this, 'render_page'],
			99
		);
	}

	function enqueue_scripts() {
		wp_enqueue_script(
			'e5_hc_selecte5',
			plugins_url('../assets/js/selecte5.full.min.js', __FILE__),
			['jquery']
		);

		wp_enqueue_style(
			'e5_hc_selecte5',
			plugins_url('../assets/css/selecte5.min.css', __FILE__)
		);

		wp_enqueue_script(
			'e5_hc_article_select',
			plugins_url('../assets/js/article-select.js', __FILE__),
			['jquery']
		);

		wp_register_style(
			'e5_hc_products_page',
			plugins_url('../assets/css/admin.css', __FILE__)
		);

		wp_enqueue_style('e5_hc_products_page');
		wp_enqueue_style('woocommerce_admin_styles');
	}

	function save() {
		// Check action
		if (!isset($_POST['e5_hc_action']) || $_POST['e5_hc_action'] !== 'save_hc_articles') {
			return;
		}

		// Validate nonce
		if (!wp_verify_nonce(wp_unslash($_POST['_wpnonce']), 'bulk-e5_hc_products')) {
			return;
		}

		// Save helloCash articles
		foreach ($_POST as $key => $_unused) {
			if (substr($key, 0, 20) === '_e5_hc_article_id_1_') {
				$product_id = substr($key, 20);
				$article_id = '';

				if (isset($_POST['_e5_hc_article_id_' . $product_id])) {
					$article_id = $_POST['_e5_hc_article_id_' . $product_id];
				}

				if (isset($article_id) && !empty($article_id)) {
					// Load Article
					$article = new WC_HC_Article($article_id);
					$article->load();

					$data = json_encode(['id' => $article_id, 'name' => $article->name]);
					update_post_meta($product_id, '_e5_hc_article_id', wp_slash($data));
				} else {
					delete_post_meta($product_id, '_e5_hc_article_id');
				}
			}
		}
	}

	function render_page() {
		$table = new WC_HC_ProductsTable();
		$table->prepare_items();

		$last_run = get_option('_e5_hc_stock_synchronizer_last_run');
		$last_run_datetime = new DateTime();
		$last_run_datetime->setTimestamp($last_run)->setTimezone(wp_timezone());
		?>
		<div class="wrap">
			<h1 class="wp-heading-inline"><?php echo __('helloCash References', 'wc-hellocash'); ?></h1>
			<hr class="wp-header-end">
			<?php if ($last_run) { ?>
				<div style="margin-top: 20px;">
					<?php echo __('Last synchronized:', 'wc-hellocash'); ?> <?php echo $last_run_datetime->format('d. m. Y, H:i (P)'); ?>
				</div>
			<?php } ?>
			<form method="post">
				<input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
				<input type="hidden" name="e5_hc_action" value="save_hc_articles" />
				<?php
				$table->search_box(__('Search Products', 'wc-hellocash'), 'e5-hc-products-search');
				?>
				<p class="search-box" style="clear: both; margin-top: 1em;">
					<input type="submit" class="button" value="<?php echo __('Save Articles', 'wc-hellocash'); ?>" />
				</p>
				<?php
				$table->display();
				?>
			</form>
		</div>
		<?php
	}
}
