<?php

if (!defined('ABSPATH')) {
	exit;
}

if (!class_exists('WP_List_Table')) {
	require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class WC_HC_ProductsTable extends WP_List_Table {
	function __construct() {
		parent::__construct(['plural' => 'e5_hc_products']);

		// Define columns for this table
		$columns = $this->get_columns();
		$hidden = [];
		$sortable = $this->get_sortable_columns();
		$primary_column = 'name';

		$this->_column_headers = [$columns, $hidden, $sortable, $primary_column];
	}

	function get_columns() {
		return [
			'thumb'			=> '<span class="wc-image"></span>' ,
			'name'			=> __('Name', 'wc-hellocash'),
			'stock'			=> __('Stock', 'wc-hellocash'),
			'hc_article'	=> __('helloCash Article', 'wc-hellocash'),
		];
	}

	function get_sortable_columns() {
		return [
			'name' =>		['name', false],
			'stock' =>		['stock', false],
			'hc_article' =>	['hc_article', false],
		];
	}

	function prepare_items() {
		// Configuration
		$per_page = 20;
		$pagenum = $this->get_pagenum();
		$rows = [];

		// Get Query Parameters
		$search_term = isset($_REQUEST['s']) ? sanitize_text_field(wp_unslash($_REQUEST['s'])) : '';
		$order_by = isset($_GET['orderby']) ? sanitize_text_field(wp_unslash($_GET['orderby'])) : '';
		$order = isset($_GET['order']) ? sanitize_text_field(wp_unslash($_GET['order'])) : '';

		// Build Query
		$meta_key = '';
		$orderby = '';

		switch ($order_by) {
			case 'name':
				$orderby = 'title';
				break;
			case 'stock':
				$meta_key = '_stock';
				$orderby = 'meta_value_num';
				break;
			case 'hc_article':
				$meta_key = '_e5_hc_article_id';
				$orderby = 'meta_value';
				break;
		}

		$ids = [];
		if ($search_term != '') {
			$data_store = WC_Data_Store::load('product');
			$ids = $data_store->search_products($search_term, '', true, true);
		}

		$products = wc_get_products([
			'limit' 	=> $per_page,
			'paginate' 	=> true,
			'page'		=> $pagenum,
			'type'		=> ['simple', 'external', 'variation'],
			'include' 	=> $ids,
			'meta_key' 	=> $meta_key,
			'orderby' 	=> $orderby,
			'order' 	=> $order
		]);

		if ($search_term != '' && count($ids) === 0) {
			// Search returned no results
			$this->set_pagination_args([
				'total_items' => 0,
				'per_page' => $per_page,
			]);

			$this->items = [];
		} else {
			$this->set_pagination_args([
				'total_items' => $products->total,
				'per_page' => $per_page,
			]);

			$this->items = $products->products;
		}
	}

	// Render functions for columns
	function column_thumb($item) {
		return $item->get_image('thumbnail');
	}

	function column_name($item) {
		$edit_id = $item->get_id();
		$display_name = $item->get_title();
		$notices = [];

		if ($item->is_type('variation')) {
			$edit_id = $item->get_parent_id();
			$notices[] = __('Variation', 'wc-hellocash');

			$variations = wc_get_formatted_variation($item, true, true, false);
			if (!empty($variations)) {
				$display_name .= ' ('. $variations . ')';
			}
		}

		if ($item->get_status() === 'draft' || $item->get_status() === 'auto-draft') {
			$notices[] = __('Draft', 'wc-hellocash');
		}

		$html = '';
		$html .= '<a href="/wp-admin/post.php?post='.$edit_id.'&action=edit">'.$display_name.'</a><br>';
		$html .= 'ID: '.$item->get_id();

		if (count($notices) > 0) {
			$html .= ' - '.implode(', ', $notices);
		}

		return $html;
	}

	function column_stock($item) {
		return $item->get_stock_quantity();
	}

	function column_hc_article($item) {
		$article_id = '';
		$article_name = '';

		$hc_article = get_post_meta($item->get_id(), '_e5_hc_article_id', true);
		if ($hc_article && !empty($hc_article)) {
			$hc_decoded = json_decode($hc_article, true);
			$article_id = $hc_decoded['id'];
			$article_name = $hc_decoded['name'];
		}

		$lang = substr(get_user_locale(), 0, 2);


		ob_start();
?>
			<input type="hidden" name="_e5_hc_article_id_1_<?php echo $item->get_id(); ?>" value="1" />
			<select
				id="_e5_hc_article_id_<?php echo $item->get_id(); ?>"
				name="_e5_hc_article_id_<?php echo $item->get_id(); ?>"
				class="_e5_hc_article select short"
				style="width: 100%;"
				lang="<?php echo $lang; ?>"
			>
				<?php if (!empty($article_id)): ?>
					<option value="<?php echo $article_id; ?>" selected="selected">
						<?php echo $article_name; ?>
					</option>
				<?php endif; ?>
			</select>
<?php
		$html = ob_get_contents();
		ob_end_clean();
		return $html;
	}

	function column_default($item, $column_name) {
		return '';
	}
}
