<?php

if (!defined('ABSPATH')) {
	exit;
}

class WC_HC_Refund {
	function __construct($order_id, $order_invoice_id) {
		$this->order_id = $order_id;
		$this->order_invoice_id = $order_invoice_id;
		$this->_communicator = new WC_HC_Communicator();
		$this->_logger = new WC_HC_Logger($order_id);
	}

	public function create() {
		$is_cancelled = get_post_meta($this->order_id, '_e5_hc_invoice_cancelled', true);

		if ($is_cancelled == true) {
			return;
		}

		// Check if feature is disabled
		$creation_disabled = false;
		$disabledOption = get_option('e5_hc_cancellation_creation_disabled');
		if (isset($disabledOption) && $disabledOption == true && $disabledOption != 'no') {
			$creation_disabled = true;
		}

		if ($creation_disabled) {
			$this->_logger->log('Cancellation Creation was disabled in the settings');
			$this->_logger->save();
			return false;
		}

		$order = wc_get_order($this->order_id);

		try {
			$version_check = get_option('e5_hc_version_data');
			if (!isset($version_check) || empty($version_check) || $this->order_id % 10 == 0) {
				$a1 = isset($version_check) ? '1' : '0';
				$a2 = empty($version_check) ? '1' : '0';
				$a3 = ($this->order_id % 10 == 0) ? '1' : '0';
				$this->_logger->log('Loading new Version Data: '.$a1.$a2.$a3);
				e5_hc_save_version_data();
				$version_check = get_option('e5_hc_version_data');
			}

			if (!isset($version_check) || empty($version_check)) {
				$a1 = isset($version_check);
				$a2 = empty($version_check);
				$this->_logger->log('No License (Version Data is Empty): '.$a1.$a2);
				$this->_logger->save();
				return false;
			}

			// Check if invoice creation is disabled
			$invoice_creation_disabled = false;
			$no_invoice_feature_enabled = apply_filters('e5_hc_no_invoice_feature_enabled', false);
			if ($no_invoice_feature_enabled) {
				$disabledOption = get_option('e5_hc_invoice_creation_deactivated');
				if (isset($disabledOption) && $disabledOption == true && $disabledOption != 'no') {
					$invoice_creation_disabled = true;
				}
			}
			
			if (!$invoice_creation_disabled) {
				$refund_text = __('Manual Refund', 'wc-hellocash');
				$result = $this->_communicator->cancel_invoice($this->order_invoice_id, $refund_text);
				
				if ($result['invoice_cancellation'] == false) {
					$this->_logger->log($this->order_invoice_id);
					$this->_logger->log(print_r($result, true));
					throw new Exception('Failed to cancel invoice');
				}
			}

			// Increase Stock
			$stock_changes = [];
			foreach ($order->get_items() as $item_id => $item) {
				$product = $item->get_product();
				$products = [$product];
			
				$children = $product->get_children();
				foreach ($children as $child) {
					$products[] = wc_get_product($child);
				}
			
				foreach ($products as $product) {
					$article_data = get_post_meta($product->get_id(), '_e5_hc_article_id', true);
			
					if (!empty($article_data)) {
						$article_data = json_decode($article_data, true);
						$article_id = $article_data['id'];
						$stock_changes[$article_id] += $item['qty'];
					}
				}
			}
			
			foreach ($stock_changes as $article_id => $qty) {
				if (!empty($article_id)) {
					$this->_communicator->increase_stock($article_id, $qty, $this->order_invoice_id);
					$this->_logger->log('Increased Stock of '.$article_id.' by '.$qty);
				}
			}
			
			update_post_meta(
				$this->order_id,
				'_e5_hc_invoice_cancelled',
				true
			);
			$this->_logger->log('Cancelled invoice with id '.$this->order_invoice_id);
			$this->_logger->save();

			$note = sprintf(__('Successfully cancelled helloCash invoice with number #%d.', 'wc-hellocash'), $result['invoice_number']);
			$order->add_order_note($note);

			return true;
		} catch (Throwable $t) {
			$this->_logger->log($t->getMessage());
			$this->_logger->save();

			$order->add_order_note(__('Failed to cancel helloCash invoice', 'wc-hellocash'));

			return false;
		}
	}
}
