<?php

if (!defined('ABSPATH')) {
	exit;
}

class WC_HC_Updater {
	public $plugin_slug;
	public $version;
	public $cache_key;
	public $cache_allowed;

	function __construct() {
		$this->plugin_slug = E5_HC_SLUG;
		$this->version = E5_HC_VERSION;
		$this->cache_key = E5_HC_SLUG . '_upd';
		$this->cache_allowed = false;

		add_filter('plugins_api', [$this, 'get_info'], 20, 3);
		add_filter('site_transient_update_plugins', [$this, 'perform_update']);
		add_action('upgrader_process_complete', [$this, 'purge_cache'], 10, 2 );
	}

	public function get_info($res, $action, $args) {
		if ($action !== 'plugin_information') {
			return false;
		}

		if ($args->slug !== $this->plugin_slug) {
			return false;
		}

		// Load new Information
		$remote = $this->_request_information();

		if (!$remote) {
			return $false;
		}

		return $this->_json_to_object($remote);
	}

	public function purge_cache() {
		if (
			$this->cache_allowed &&
			$options['action'] === 'update' &&
			$options['type'] === 'plugin'
		) {
			delete_transient($this->cache_key);
		}
	}

	public function perform_update($transient) {
		if (empty($transient->checked)) {
			return $transient;
		}

		$remote = $this->_request_information();

		if (
			$remote &&
			version_compare($this->version, $remote->version, '<') &&
			version_compare($remote->requires, get_bloginfo('version'), '<') &&
			version_compare($remote->requires_php, PHP_VERSION, '<')
		) {
			$res = $this->_json_to_object($remote);
			$transient->response[$res->plugin] = $res;
		}

		return $transient;
	}

	private function _request_information() {
		$remote = get_transient($this->cache_key);

		if ($remote === false || !$this->cache_allowed) {
			$remote = wp_remote_get(
				E5_HC_BASE_URL . '/releases/wc-hellocash/info.json',
				[
					'timeout' => 10,
					'headers' => [
						'Accept' => 'application/json'
					]
				]
			);

			if (
				is_wp_error($remote) ||
				wp_remote_retrieve_response_code($remote) !== 200 ||
				empty(wp_remote_retrieve_body($remote))
			) {
				return false;
			}

			set_transient($this->cache_key, $remote, DAY_IN_SECONDS);
		}

		$remote = json_decode(wp_remote_retrieve_body($remote));
		return $remote;
	}

	private function _json_to_object($remote) {
		$res = new stdClass();
		$res->name = $remote->name;
		$res->slug = $remote->slug;
		$res->version = $remote->version;
		$res->new_version = $remote->version;
		$res->tested = $remote->tested;
		$res->requires = $remote->requires;
		$res->author = $remote->author;
		$res->author_profile = $remote->author_profile;
		$res->download_link = $remote->download_url;
		$res->package = $remote->download_url;
		$res->trunk = $remote->download_url;
		$res->requires_php = $remote->requires_php;
		$res->last_updated = $remote->last_updated;

		$res->plugin = E5_HC_SLUG . '/' . E5_HC_SLUG . '.php';

		$res->sections = array(
			'description' => $remote->sections->description,
			'installation' => $remote->sections->installation,
			'changelog' => $remote->sections->changelog
		);

		if (!empty($remote->banners)) {
			$res->banners = [
				'low' => $remote->banners->{'1x'},
				'high' => $remote->banners->{'2x'},
			];
		}

		if (!empty($remote->icons)) {
			$res->icons = [
				'1x' => $remote->icons->{'1x'},
				'2x' => $remote->icons->{'2x'},
			];
		}

		return $res;
	}
}


new WC_HC_Updater();
