<?php

if (!defined('ABSPATH')) {
	exit;
}


function e5_hc_email_attachment_filter($attachments, $email_id, $order) {
	if (!is_a($order, 'WC_Order') || !isset($email_id)) {
		return $attachments;
	}

	if ($email_id != 'customer_invoice' && $email_id != 'customer_processing_order' && $email_id != 'customer_completed_order') {
		return $attachments;
	}

	try {
		$wc_settings = get_option('woocommerce_'.$email_id.'_settings');
		if (isset($wc_settings['e5_hc_attach_hellocash_pdf']) && ($wc_settings['e5_hc_attach_hellocash_pdf'] == true && $wc_settings['e5_hc_attach_hellocash_pdf'] != 'no')) {
			$tmp_folder = get_temp_dir() . $order->get_id();

			if (!file_exists($tmp_folder)) {
				if (!mkdir($tmp_folder, 0777, true)) {
					return $attachments;
				}
			}

			$invoice = new WC_HC_Invoice($order->get_id());
			$content = $invoice->download();
			$filename = $tmp_folder . '/' . $order->get_id() . '.pdf';
			file_put_contents($filename, $content);

			$attachments[] = $filename;
		}
	} catch (Throwable $t) {
		$logger = new WC_HC_Logger($order->get_id());
		$logger->log($t->getMessage());
		$logger->save();
	}

	return $attachments;
}

add_filter('woocommerce_email_attachments', 'e5_hc_email_attachment_filter', 10, 3);


function e5_hc_clean_temp_folder($return, $email_id, $email) {
	if (!isset($email_id)) {
		return;
	}

	if ($email_id != 'customer_invoice' && $email_id != 'customer_processing_order' && $email_id != 'customer_completed_order') {
		return;
	}

	$order = $email->object;
	$tmp_folder = get_temp_dir() . $order->get_id();
	if (file_exists($tmp_folder)) {
		try {
			require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-base.php';
			require_once ABSPATH . 'wp-admin/includes/class-wp-filesystem-direct.php';

			$fileSystemDirect = new WP_Filesystem_Direct(false);
			$fileSystemDirect->rmdir($tmp_folder, true);
		} catch (Throwable $t) {
			$logger = new WC_HC_Logger($order->get_id());
			$logger->log($t->getMessage());
			$logger->save();
		}
	}
}

add_action('woocommerce_email_sent', 'e5_hc_clean_temp_folder', 10, 3);


// Settings

function e5_hc_settings_api_form_fields_invoice($form_fields) {
	$form_fields['e5_hc_attach_hellocash_pdf'] = [
		'title' => __( 'Attach helloCash PDF Invoice', 'wc-hellocash' ),
		'description' => __( 'Attach the helloCash generated PDF invoice to this email', 'wc-hellocash' ),
		'type' => 'checkbox',
		'default' => '',
	];

	return $form_fields;
}

add_action('woocommerce_settings_api_form_fields_customer_invoice', 'e5_hc_settings_api_form_fields_invoice', 10, 1);


function e5_hc_settings_api_form_fields_processing($form_fields) {
	$form_fields['e5_hc_attach_hellocash_pdf'] = [
		'title' => __( 'Attach helloCash PDF Invoice', 'wc-hellocash' ),
		'description' => __( 'Attach the helloCash generated PDF invoice to this email', 'wc-hellocash' ),
		'type' => 'checkbox',
		'default' => '',
	];

	return $form_fields;
}

add_action('woocommerce_settings_api_form_fields_customer_processing_order', 'e5_hc_settings_api_form_fields_processing', 10, 1);


function e5_hc_settings_api_form_fields_completed($form_fields) {
	$form_fields['e5_hc_attach_hellocash_pdf'] = [
		'title' => __( 'Attach helloCash PDF Invoice', 'wc-hellocash' ),
		'description' => __( 'Attach the helloCash generated PDF invoice to this email', 'wc-hellocash' ),
		'type' => 'checkbox',
		'default' => '',
	];

	return $form_fields;
}

add_action('woocommerce_settings_api_form_fields_customer_completed_order', 'e5_hc_settings_api_form_fields_completed', 10, 1);
