<?php

if (!defined('ABSPATH')) {
	exit;
}


function e5_hc_product_article_field() {
	global $post;

	if ($post->post_type != 'product') {
		return;
	}

	$article_id = '';
	$article_name = '';

	$hc_article = get_post_meta($post->ID, '_e5_hc_article_id', true);
	if ($hc_article && !empty($hc_article)) {
		$hc_decoded = json_decode($hc_article, true);
		$article_id = $hc_decoded['id'];
		$article_name = $hc_decoded['name'];
	}

	$lang = substr(get_user_locale(), 0, 2);
?>
	<div class="options_group hide_if_variable">
		<p class="form-field">
			<label for="_e5_hc_article_id">
				<?php echo __('helloCash Article', 'wc-hellocash'); ?>
			</label>
			<select
				id="_e5_hc_article_id"
				name="_e5_hc_article_id"
				class="_e5_hc_article select short"
				lang="<?php echo $lang; ?>"
			>
				<?php if (!empty($article_id)): ?>
					<option value="<?php echo $article_id; ?>" selected="selected">
						<?php echo $article_name; ?>
					</option>
				<?php endif; ?>
			</select>
		</p>
	</div>
<?php
}

add_action('woocommerce_product_options_general_product_data', 'e5_hc_product_article_field');


function e5_hc_product_article_field_save($post_id) {
	if (isset($_POST['_e5_hc_article_id']) && !empty(isset($_POST['_e5_hc_article_id']))) {
		$article_id = $_POST['_e5_hc_article_id'];

		// Load Article
		$article = new WC_HC_Article($article_id);
		$article->load();

		$data = json_encode(['id' => $article_id, 'name' => $article->name]);
		update_post_meta($post_id, '_e5_hc_article_id', wp_slash($data));
	} else {
		delete_post_meta($post_id, '_e5_hc_article_id');
	}
}

add_action('woocommerce_process_product_meta', 'e5_hc_product_article_field_save');


function e5_hc_variable_product_article_field($loop, $variation_data, $variation) {
	$article_id = '';
	$article_name = '';

	$hc_article = get_post_meta($variation->ID, '_e5_hc_article_id', true);
	if ($hc_article && !empty($hc_article)) {
		$hc_decoded = json_decode($hc_article, true);
		$article_id = $hc_decoded['id'];
		$article_name = $hc_decoded['name'];
	}

	$lang = substr(get_user_locale(), 0, 2);
?>
	<p class="form-row form-row-full form-field">
		<label for="_e5_hc_article_id_<?php echo $variation->ID; ?>">
			<?php echo __('helloCash Article', 'wc-hellocash'); ?>
		</label>
		<select
			id="_e5_hc_article_id_<?php echo $variation->ID; ?>"
			name="_e5_hc_article_id_<?php echo $variation->ID; ?>"
			class="_e5_hc_article select short"
			style="width: 100%;"
			lang="<?php echo $lang; ?>"
		>
			<?php if (!empty($article_id)): ?>
				<option value="<?php echo $article_id; ?>" selected="selected">
					<?php echo $article_name; ?>
				</option>
			<?php endif; ?>
		</select>
	</p>
<?php
}

add_action('woocommerce_variation_options_pricing', 'e5_hc_variable_product_article_field', 10, 3);


function e5_hc_variable_product_article_field_save($variation_id, $i) {
	if (isset($_POST['_e5_hc_article_id_'.$variation_id]) && !empty($_POST['_e5_hc_article_id_'.$variation_id])) {
		// Load Article
		$article_id = $_POST['_e5_hc_article_id_'.$variation_id];
		$article = new WC_HC_Article($article_id);
		$article->load();

		$data = json_encode(['id' => $article_id, 'name' => $article->name]);
		update_post_meta($variation_id, '_e5_hc_article_id', wp_slash($data));
	} else {
		delete_post_meta($variation_id, '_e5_hc_article_id');
	}
}

add_action('woocommerce_save_product_variation', 'e5_hc_variable_product_article_field_save', 10, 2);


function e5_hc_ajax_article_search() {
	$query = strtolower($_GET['q']);

	$result = [];

	// Load all(!) articles
	$communicator = new WC_HC_Communicator();
	$articles = $communicator->load_all_articles();

	foreach ($articles as $article) {
		$name = strtolower($article['article_name']);
		if (strpos($name, $query) !== false) {
			$result[] = [
				'id' => $article['article_id'],
				'name' => $article['article_name']
			];
		}
	}

	echo json_encode($result);
	wp_die();
}

add_action('wp_ajax_hc_article_search', 'e5_hc_ajax_article_search');


function e5_hc_admin_scripts() {
	wp_enqueue_script(
		'e5_hc_selecte5',
		plugins_url('../assets/js/selecte5.full.min.js', __FILE__),
		['jquery']
	);

	wp_enqueue_style(
		'e5_hc_selecte5',
		plugins_url('../assets/css/selecte5.min.css', __FILE__)
	);

	wp_enqueue_script(
		'e5_hc_article_select',
		plugins_url('../assets/js/article-select.js', __FILE__),
		['jquery']
	);

	wp_enqueue_script(
		'e5_hc_article_select_de',
		plugins_url('../assets/js/i18n/de.js', __FILE__),
		['jquery']
	);
}

add_action('admin_enqueue_scripts', 'e5_hc_admin_scripts');
