<?php

if (!defined('ABSPATH')) {
	exit;
}

function e5_hc_product_save($product_id, $product, $update, $save_variation = false) {
	// Check if feature is enabled
	$enabledOption = get_option('e5_hc_auto_create_articles_enable');
	$articles_feature_enabled = apply_filters('e5_hc_article_creation_feature_enabled', false);
	if (!$articles_feature_enabled || !$enabledOption) {
		return;
	}

	$logger = new WC_HC_Logger('_e5_hc_product_creation_log');

	// ignore autosave
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
		$logger->log('Skipping autosave');
		$logger->save();
		return;
	}

	if ($update === false) {
		// When creating a new product remember that we should later on create the article
		update_post_meta($product_id, '_e5_hc_should_create_article', true);
		$logger->log('set should_create_article to true');
		$logger->save();
		return;
	}

	$should_create_article = get_post_meta($product_id, '_e5_hc_should_create_article', true);
	if ($update === true && ($should_create_article !== true && $should_create_article !== 1 && $should_create_article !== '1')) {
		$logger->log('is_update but should_create_article is not true');
		$logger->save();
		return;
	}

	// check if this is the parent product of variants
	if ($product->is_type('variable')) {
		$logger->log('not creating main variable product');
		$logger->save();
		return;
	}

	if ($product->is_type('variation') && $save_variation === false) {
		$logger->log('not creating variation product');
		$logger->save();
		return;
	}

	update_post_meta($product_id, '_e5_hc_should_create_article', false);
	$logger->log('setting should_create_article to false and creating article');

	// check if a helloCash article was linked
	$product_hc_article = get_post_meta($product_id, '_e5_hc_article_id', true);
	if (!empty($product_hc_article)) {
		$logger->log('not creating already existing helloCash article');
		$logger->save();
		return;
	}

	// now we can actually create and link the helloCash article
	try {
		$communicator = new WC_HC_Communicator();
		$result = $communicator->create_article($product);

		if (!empty($result) && !empty($result['article_id'])) {
			$article_id = $result['article_id'];
			$article_name = $result['article_name'];

			$data = json_encode(['id' => $article_id, 'name' => $article_name]);
			update_post_meta($product_id, '_e5_hc_article_id', wp_slash($data));
		} else {
			$logger->log('Could not create helloCash article from product: '.$product->get_id());
			$logger->save();
		}
	} catch (Throwable $t) {
		$logger->log($t->getMessage());
		$logger->save();
	}

	$logger->save();
}

function e5_hc_insert_post($product_id, $post, $update) {
	if ($post->post_type !== 'product' && $post->post_type !== 'product_variation') {
		return;
	}

	$product = wc_get_product($product_id);
	e5_hc_product_save($product_id, $product, $update, false);
}
add_action('wp_insert_post', 'e5_hc_insert_post', 99, 3);


function e5_hc_product_save_variation($variation_id, $i) {
	$product = wc_get_product($variation_id);
	e5_hc_product_save($variation_id, $product, true, true);
}
add_action('woocommerce_save_product_variation', 'e5_hc_product_save_variation', 99, 2);

