<?php
/**
 * Plugin Name: helloCash for WooCommerce
 * Version: 1.3.11
 * Plugin URI: https://shop.elephants5.com/product/hellocash-woocommerce-plugin
 * Description: Connect WooCommerce to helloCash to automatically generate invoices.
 * Author: ELEPHANTS 5
 * Author URI: https://elephants5.com
 * Text Domain: wc-hellocash
 * Domain Path: /languages
 *
 */

if (!defined('ABSPATH')) {
	exit;
}

define('E5_HC_PLUGIN_NAME', __('helloCash for WooCommerce', 'wc-hellocash'));
define('E5_HC_PLUGIN_DESCRIPTION', __('Connect WooCommerce to helloCash to automatically generate invoices.', 'wc-hellocash'));
define('E5_HC_BASE_URL', 'https://shop.elephants5.com');
define('E5_HC_SLUG', 'wc-hellocash');
define('E5_HC_VERSION', '1.3.11');


// Load Dependencies
require_once(__DIR__ . '/includes/class-hc-logger.php');
require_once(__DIR__ . '/includes/class-hc-communicator.php');
require_once(__DIR__ . '/includes/class-hc-invoice.php');
require_once(__DIR__ . '/includes/class-hc-refund.php');
require_once(__DIR__ . '/includes/class-hc-article.php');
require_once(__DIR__ . '/includes/class-hc-updater.php');
require_once(__DIR__ . '/includes/class-hc-stock-synchronizer.php');
require_once(__DIR__ . '/includes/class-hc-products-page.php');
require_once(__DIR__ . '/includes/class-hc-products-table.php');
require_once(__DIR__ . '/includes/class-hc-categories-page.php');
require_once(__DIR__ . '/includes/class-hc-categories-table.php');

require_once(__DIR__ . '/includes/hook-hc-email.php');
require_once(__DIR__ . '/includes/hook-hc-order-status.php');
require_once(__DIR__ . '/includes/hook-hc-product-article-field.php');
require_once(__DIR__ . '/includes/hook-hc-order.php');
require_once(__DIR__ . '/includes/hook-hc-product.php');


// Load Objects
new WC_HC_Stock_Synchronizer();
new WC_HC_Products_Page();
new WC_HC_Categories_Page();

// Register basic plugin Hooks
function e5_hc_init() {
	load_plugin_textdomain('wc-hellocash', false, basename( dirname( __FILE__ ) ) . '/languages/');
}

add_action('init', 'e5_hc_init');


function e5_hc_plugin_actions($actions) {
	if (is_plugin_active(plugin_basename(__FILE__))) {
		$link = '<a href="' . admin_url('admin.php?page=wc-settings&tab=hellocash') . '">' . __('Settings', 'wc-hellocash') . '</a>';
		$actions = array_merge([$link], $actions);
	}
	return $actions;
}

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'e5_hc_plugin_actions');


function e5_hc_plugin_meta($links_array, $plugin_file_name) {
	if (strpos($plugin_file_name, basename(__FILE__))) {
		$links_array[] = '<a href="' . E5_HC_BASE_URL . '/dokumentation" target="_blank">' . __('Documentation', 'wc-hellocash') . '</a>';
	}

	return $links_array;
}

add_filter('plugin_row_meta', 'e5_hc_plugin_meta', 10, 2);


function e5_hc_plugin_activation() {
	$data = get_plugin_data(__FILE__, false, false);

	if (get_option('e5_hc_version') != $data['Version']) {
		delete_option('e5_hc_version');
		add_option('e5_hc_version', $data['Version']);
		?>
			<div class="notice notice-success is-dismissible">
				<h3>
					<?php _e('Thank you for using helloCash for WooCommerce!', 'wc-hellocash'); ?>
				</h3>
				<p>
					<?php _e('Please configure the Plugin in the ', 'wc-hellocash'); ?>
					<a class="button" href="<?php echo admin_url('admin.php?page=wc-settings&tab=hellocash') ?>"><?php _e('Settings', 'wc-hellocash'); ?></a>
				</p>
			</div>
		<?php
	}

	$version_check = get_option('e5_hc_version_data');
	if (!isset($version_check) || empty($version_check)) {
		?>
			<div class="notice notice-error">
				<h3>
					<?php _e('License Error', 'wc-hellocash'); ?>
				</h3>
				<p>
					<?php _e('Please active helloCash for WooCommerce. Otherwise no invoices will be created.', 'wc-hellocash'); ?>
					<a class="button" href="<?php echo admin_url('admin.php?page=wc-settings&tab=hellocash') ?>"><?php _e('Settings', 'wc-hellocash'); ?></a>
					<a class="button" href="https://shop.elephants5.com"><?php _e('Buy a License', 'wc-hellocash'); ?></a>
				</p>
			</div>
		<?php
	}

	$data = json_decode(base64_decode($version_check));
	if (!empty($data)) {
		// Check expiration date
		$expiration_date = date_create_from_format('Y-m-d H:i',
			$data->validUntil
		);
		$now = new DateTime();
		$now->add(new DateInterval('P1M'));
		if ($now > $expiration_date) {
			?>
			<div class="notice notice-warning">
				<h3>
					<?php _e('License Expiration', 'wc-hellocash'); ?>
				</h3>
				<p>
					<?php printf(__("Your license for the helloCash WooCommerce Plugin expires on %s. Please extend it before this date to ensure seamless operation of the plugin.", 'wc-hellocash'), $expiration_date->format('d. m. Y')); ?>
					<br />
					<a class="button" target="_blank" href="https://shop.elephants5.com/wp-admin/admin-ajax.php?action=extend_licensecode&code=<?php echo $data->code; ?>"><?php _e('Extend License', 'wc-hellocash'); ?></a>
				</p>
			</div>
			<?php
		}
	}
}

add_action('admin_notices', 'e5_hc_plugin_activation');


function e5_hc_plugin_deactivation() {
	// Delete Version Data
	delete_option('e5_hc_version');

	// Remove Cron Job (if it was registered)
	wp_clear_scheduled_hook('e5_hc_stock_synchronizer_cron');
}

register_deactivation_hook(__FILE__, 'e5_hc_plugin_deactivation');


function e5_hc_register_settings_page($settings) {
	$settings[] = include __DIR__ . '/settings/class-wc-settings-hellocash.php';
	return $settings;
}

add_filter('woocommerce_get_settings_pages', 'e5_hc_register_settings_page');


function e5_hc_save_version_data() {
	$version = get_option('e5_hc_license_code');
	if (isset($version) && !empty($version)) {
		$domain = parse_url(home_url())['host'];
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, E5_HC_BASE_URL . '/wp-admin/admin-ajax.php?action=check_licensecode');
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_POSTFIELDS, [
			'code' => $version,
			'domain' => $domain,
		]);

		$response = curl_exec($ch);
		curl_close($ch);

		$result_array = json_decode($response, true);

		delete_option('e5_hc_version_data');
		if (isset($result_array['code']) && $result_array['code'] == $version) {
			if (isset($result_array['validUntil']) && strtotime($result_array['validUntil']) >= time()) {
				if (isset($result_array['domains'])) {
					foreach ($result_array['domains'] as $dom) {
						if (strpos($domain, $dom) !== false) {
							add_option('e5_hc_version_data', base64_encode(json_encode($result_array)), '', 'yes');
						}
					}
				}
			}
		}
	} else {
		delete_option('e5_hc_version_data');
	}
}

function e5_hc_api_token_warning() {
	if (empty(get_option('e5_hc_api_token'))) {
		?>
		<div class="notice notice-error">
			<h3>
				<?php _e('URGENT: API Token Required', 'wc-hellocash'); ?>
			</h3>
			<p>
				<?php _e("helloCash requires us to switch to API Token based authentication. Please generate a Token in helloCash > Cash Register > Settings > General > helloCash API and enter it in the plugin settings. Otherwise we will no longer be able to create invoices or synchronise your stock.", 'wc-hellocash'); ?>
			</p>
			<p>
				<a class="button" target="_blank" href="<?php echo admin_url('admin.php?page=wc-settings&tab=hellocash') ?>"><?php _e('Enter API Token', 'wc-hellocash'); ?></a>
			</p>
		</div>
		<?php
	}
}

add_action('admin_notices', 'e5_hc_api_token_warning');


// Debug Logs Download
function e5_hc_download_debug_logs() {
	header('Content-Type: text/plain');
	header('Content-Disposition: attachment; filename="e5_hellocash.log"');

	// Get General Information
	echo "HELLOCASH FOR WOOCOMMERCE DEBUG LOG\n";
	echo "Plugin-Version: " . E5_HC_VERSION . "\n";

	// WordPress Version
	require_once(ABSPATH . WPINC . '/version.php');
	global $wp_version;
	echo "WP-Version: " . $wp_version . "\n";
	echo "PHP-Version: " . PHP_VERSION . "\n";
	echo "Date: ".gmdate('c')."\n\n";


	// Plugin Settings
	echo "HELLOCASH SETTINGS:\n";
	$all_options = wp_load_alloptions();
	foreach ($all_options as $key => $value) {
		if (strpos($key, 'e5_hc_') !== false && strpos($key, 'log') === false && strpos($key, 'api_token') === false) {
			echo "\t" . $key . ": " . $value . "\n";
		}
	}


	// Get last 20 orders
	echo "\n\nLAST 20 ORDERS";
	$query = new WC_Order_Query([
		'limit' => 20,
		'orderby' => 'date',
		'order' => 'DESC',
	]);
	$orders = $query->get_orders();
	foreach ($orders as $order) {
		echo "\nOrder #" . $order->get_id() . "\n";
		echo "\tDate: " . $order->get_date_created() . "\n";
		echo "\tStatus: " . $order->get_status() . "\n";
		echo "\tMetas:\n";

		$metas = get_post_meta($order->get_id());
		foreach ($metas as $key => $value) {
			if (strpos($key, 'e5_hc_') !== false && count($value) > 0) {
				echo "\t" . $key . ": " . $value[0] . "\n";
			}
		}

		echo "------------------------------------------\n";
	}


	// Get stock synchronizer log
	$stock_log_data = get_option('_e5_hc_stock_synchronizer_log');
	echo "\n\nSTOCK SYNC LOG:\n" . $stock_log_data;

	// Get product creation log
	$product_log_data = get_option('_e5_hc_product_creation_log');
	echo "\n\nPRODUCT CREATION LOG:\n" . $product_log_data;


	// Installed Plugins
	echo "\n\nOTHER INSTALLED PLUGINS:\n";
	include_once( 'wp-admin/includes/plugin.php' );
	$all_plugins = get_plugins();
	$active_plugins = get_option('active_plugins');

	foreach ( $all_plugins as $key => $value ) {
		$is_active = (in_array($key, $active_plugins)) ? 'active' : 'inactive';
		echo "\n" . $key . "\n";
		echo "\tName: " . $value['Name'] . "\n";
		echo "\tVersion: " . $value['Version'] . "\n";
		echo "\tActive: " . $is_active . "\n";
	}

	// Done
	echo "\n\nEND OF LOG";

	wp_die();
	die();
}

add_action('wp_ajax_e5_hc_download_debug_logs', 'e5_hc_download_debug_logs');
